/********************************************************
 * batch_r -- Function for handling batches during 	*
 * restore operations.  This is small since most of 	*
 * the work is done in the various batch objects.	*
 ********************************************************/
#include "magic.h"
#include "exception.h"
#include "colon.h"
#include "collect_batch_r.h"
#include "slice_batch_r.h"
#include "util.h"
#include "backup.h"
#include "log.h"
#include "batch_r.h"

/********************************************************
 * read_batch -- Read a batch information record	*
 * 	and return a pointer to it.			*
 ********************************************************/
batch_info_r* const read_batch(
    std::istream &in_file	// File containing the meta data
) 
{
    std::string type_name;	// Type of batch
    string_set file_list;	// List of files in the batch
    int n_files;		// Number of files in the batch

    batch_info_r batch_info;	// Information about the batch

    colon_line parser(in_file);

    parser.expect_line(META_BATCH_TYPE, "Error reading batch information",
	    __FILE__, __LINE__);
    batch_info.type = parser.get_value();

    parser.expect_line(META_BATCH_NUMBER, "Error reading batch information",
	    __FILE__, __LINE__);
    batch_info.batch_number = static_cast<unsigned int>(
	    parser.get_int_value("Batch number is not a number"));

    parser.expect_line(META_BATCH_NAME, "Error reading batch name",
	    __FILE__, __LINE__);
    batch_info.name = parser.get_value();

    parser.expect_line(META_BATCH_NAMES_NEEDED, "Error readings names needed flag",
	    __FILE__, __LINE__);
    batch_info.names_needed = parser.get_int_value("Error reading names needed flag");

    parser.expect_line(META_BATCH_BACKUP_CMD, "Error reading backup command",
	    __FILE__, __LINE__);
    batch_info.backup_cmd = parser.get_value();

    parser.expect_line(META_BATCH_RESTORE_CMD, "Error reading restore command",
	    __FILE__, __LINE__);
    batch_info.restore_cmd = parser.get_value();

    parser.expect_line(META_BATCH_VERIFY_CMD, "Error reading verify command",
	    __FILE__, __LINE__);
    batch_info.verify_cmd = parser.get_value();

    parser.expect_line(META_BATCH_FILES, "Error reading batch information",
	    __FILE__, __LINE__);
    n_files = parser.get_int_value("Error reading batch information");

    // Loop through the file list and read things
    for (int i = 0; i < n_files; ++i) {
	std::string line;	// Line from the input file

	std::getline(in_file, line);
	batch_info.files.insert(decode_string(line));
    }
    if (str_eq(batch_info.type, BATCH_TYPE_COLLECTION)) {
	return (new collection_batch_info_r(batch_info, in_file));
    }
    if (str_eq(batch_info.type, BATCH_TYPE_SLICE)) {
	return (new slice_batch_info_r(batch_info, in_file));
    }
    INTERNAL_ERROR("Invalid type name " + type_name + " for batch module");
}

/********************************************************
 * new_batch_r -- Create a batch restore object		*
 ********************************************************/
batch_r* new_batch_r(
    const std::string& type_name 	// Type of batch to create
)
{
    if (str_eq(type_name, BATCH_TYPE_COLLECTION)) {
	return (new collection_batch_r());
    }
    if (str_eq(type_name, BATCH_TYPE_SLICE)) {
	return (new slice_batch_r());
    }
    USER_ERROR("Invalid type name " + type_name + " for batch module");
}
