/********************************************************
 * cd_io_r -- Module to handle the restore I/O for CD	*
 ********************************************************/
#ifndef __CD_IO_R_H__
#define __CD_IO_R_H__
#include "magic.h"

#include "io_r.h"
#include "cd_io_c.h"

/********************************************************
 * cd_io_r -- Class to handle restore i/o from a CD	*
 ********************************************************/
class cd_io_r: public io_r, public cd_io_c {
    private:
	cd_label label;	// The label for the CD

	enum IN_OUT {CD_EJECT_OUT, CD_EJECT_IN};
    public:
	cd_io_r(
	    const std::string& name,
	    const config& config
	): cd_io_c(name, config) {}
	~cd_io_r() {};

    private:
	cd_io_r(const cd_io_r&);	// No copy constructor
	cd_io_r& operator = (const cd_io_r&);//No assignment operator
    public:
	// Read the meta file
	std::string get_meta(void);

	// Read the given file from the disk and return it's name
	std::string get_file(const io_info_r* info);

	// Remove a file after we've used it
	void rm_file(const std::string& file)
	{
	    // On a CD this is nothing because we don't
	    // use temp files.  (We get the file from the CD)
	}
	
	// Get the current media number
	int get_cur_media(void);
    private:
	void load_cd(
	    const int cd_number	// Number of the cd to be loaded
	);
	void eject(
	    const IN_OUT flag
	);
};

/********************************************************
 * cd_io_info_r -- Information about the CD batch	*
 ********************************************************/
class cd_io_info_r : public io_info_r {
    public:
	std::string file_name;	// File name on the disk

	cd_io_info_r(const unsigned int i_media_sequence,
		     const unsigned int i_file_sequence
	):
	    io_info_r(IO_TYPE_CD, i_media_sequence, i_file_sequence)
	{}
	// Copy Constructor defaults
	// Assignment operator defaults
	// Destructor defaults
    public:
	void read(std::istream& in_file);
};

#endif /* __CD_IO_R_H__ */

