/********************************************************
 * colon_line -- Parse lines of the form:		*
 * 							*
 * KEYWORD: value					*
 ********************************************************/
#include "util.h"
#include "colon.h"

/********************************************************
 * colon_line::get-line -- Read and decode a line	*
 * 							*
 * Throws an exception on error.			*
 ********************************************************/
void colon_line::get_line(
    const std::string& error	// Error message
)
{
    // Position of the colon in the string
    std::string::size_type colon_pos;

    getline(in_file, line);
    colon_pos = line.find_first_of(':');
    if (colon_pos == std::string::npos) {
	INTERNAL_ERROR(error);
    }

    // The keyword and value from the line
    keyword = line.substr(0, colon_pos);
    value = line.substr(colon_pos+2);
}
/********************************************************
 * expect_line -- Read a line, expect a given keyword	*
 * 							*
 * Throws an exception on error.			*
 ********************************************************/
void colon_line::expect_line(
    const std::string expect_key,	// The expected key
    const std::string& error_msg,	// Error message if we did not get it
    const char* const file,		// File where we were called
    const int prog_line			// Line where called
)
{
    get_line(error_msg);
    if (expect_key != keyword) 
	INTERNAL_ERROR("Expected " + expect_key + " got " + keyword +
		"(" + file + ":" + int_to_string(prog_line) + ")");
}

