/********************************************************
 * Test the filer					*
 ********************************************************/
#include <getopt.h>
#include <stdlib.h>
#include <fstream>
#include <sys/param.h>
#include <unistd.h>
#include <errno.h>

#include "config.h"
#include "tmp_file.h"
#include "backup.h"
#include "input_list.h"
#include "filer.h"

config global_config;	// The configuration

bool keep_option = false;	// Keep temp files
bool image_option = false;	// Keep image files

bool do_log_option = false;	// If set, log things

std::ofstream log_file;		// File for logging things
std::string backup_root("/");	// Root of the backups

file_table global_file_table;	// master name->index table

// Directory from which we started this mess
static char old_dir[MAXPATHLEN];

int main(int argc, char *argv[])
{
    try {
	// Name of the log file (if any)
	//
	global_config.read("filer_test.txt");
	tmp_name_init(global_config);

	if (global_config.defined("Options", "Global", "BackupRoot", 0)) {
	    backup_root = global_config.get_option(
		    "Options", "Global", "BackupRoot");
	}
	
	if (getcwd(old_dir, sizeof(old_dir)) == NULL) {
	    SYSTEM_ERROR("getcwd failed");
	}

	// Input list we are using
	input_list input("FilerTest", global_config);

	// The files from this list
	string_set files = input.find_files();

	std::cout << "InputList Files:\n";
	for (string_set::const_iterator cur_file = files.begin();
		cur_file != files.end();
		++cur_file) {
	    std::cout << '\t' << (*cur_file) << '\n';
	}
	std::cout << "\n";

	// Filer for testing
	filer the_filer;
	
	// The files we are using
	the_filer.add_files(files);

	file_table::file_index_set g_files = the_filer.get_files();
	std::cout << "Filer Files:\n";
	for (file_table::file_index_set::const_iterator cur_file = g_files.begin();
		cur_file != g_files.end();
		++cur_file) {
	    std::cout << '\t' << (*cur_file) << '\n';
	}
	std::cout << "\n";

	g_files = the_filer.all_names("filer_test.dir/foo");
	std::cout << "all_names(foo):\n";
	for (file_table::file_index_set::const_iterator cur_file = g_files.begin();
		cur_file != g_files.end();
		++cur_file) {
	    std::cout << '\t' << (*cur_file) << '\n';
	}
	std::cout << "\n";

	g_files = the_filer.all_names("filer_test.dir/bar_a");
	std::cout << "all_names(bar_a):\n";
	for (file_table::file_index_set::const_iterator cur_file = g_files.begin();
		cur_file != g_files.end();
		++cur_file) {
	    std::cout << (*cur_file) << '\n';
	}
	std::cout << "\n";

	std::cout << "Marking bar\n";
	the_filer.mark(g_files);

	g_files = the_filer.get_files();
	std::cout << "Filer Files:\n";
	for (file_table::file_index_set::const_iterator cur_file = g_files.begin();
		cur_file != g_files.end();
		++cur_file) {
	    std::cout << '\t' << (*cur_file) << '\n';
	}
	std::cout << '\n';

    } 
    catch (user_error &err) {
	err.print();
    }
    catch (internal_error &err) {
	err.print();
    }
    catch (system_error &err) {
	err.print();
    }
    catch (generic_error &err) {
	std::cerr << "Internal error: Strange error caught" << std::endl;
	err.print();
    }
    return (0);
}
