/********************************************************
 * Information about both backup and restore I/Os	*
 ********************************************************/
#ifndef __IO_C_H__
#define __IO_C_H__
#include <string>

/********************************************************
 * head / tail section we add to the file data		*
 * for each file we put on the device.			*
 ********************************************************/
const unsigned long int HEAD_MAGIC =
    (('H' << 24) | ('E' << 16) | ('A' << 8) | ('D'));

// For portability, we are using unsigned long int for everything
struct file_head {
    unsigned long int magic;		//[B] Magic number 
    unsigned long int struct_size;	//[B] Structure size
    unsigned long int backup_number;	//[B] Backup serial number
    unsigned long int size;		//[B] Size of the data in the file
    unsigned long int media_sequence;	//[I] Media sequence number
    unsigned long int file_sequence;	//[I] File sequence number
    unsigned long int slice_number;	//[B] Current slice number
    unsigned long int last;		//[B] True if the last slice
    unsigned long int crc;		//[B] CRC code
};
// NOTE: B--Filled in by batcher.  I--Filled in by I/O

const unsigned long int TAIL_MAGIC =
    (('T' << 24) | ('A' << 16) | ('I' << 8) | ('L'));

struct file_tail {
    unsigned long int magic;		//[B] Magic number
    unsigned long int struct_size;	//[B] Structure size
};

/********************************************************
 * io_info_c -- Information about an I/O.  Common	*
 * to both backup and restore.				*
 ********************************************************/
class io_info_c {
    public:
	const char* type;	// Type of I/O
	unsigned int media_sequence;	// Media sequence where the batch is
	unsigned int file_sequence;	// File seq -- File where the batch is

    public:
	io_info_c(const char* i_type,
		  const unsigned int i_media_sequence,
		  const unsigned int i_file_sequence
	):
	    type(i_type),
	    media_sequence(i_media_sequence),
	    file_sequence(i_file_sequence) 
	{}
	virtual ~io_info_c() {}
	// Copy Constructor defaults
	// Assignment operator defaults
};

#endif /* __IO_C_H__ */
