/********************************************************
 * log -- Handle the logging.  The constants define	*
 * the various log categories.  The log_msg function	*
 * does the work.					*
 ********************************************************/
#ifndef __LOG_H__
#define __LOG_H__
#include <string>
#include <fstream>

enum log_type {
    LOG_WARNING = 'w',	// Warning messages
    LOG_ERROR = 'e',	// Error messages
    LOG_CMD = 'c',	// Command output
    LOG_VERIFY = 'v',	// Verify output

    LOG_INFO = 'i',	// Information
    LOG_PIPE = 'p',	// Pipe warnings
    LOG_DIR = 'd',	// Directory warnings

    LOG_PROGRESS = 'g',	// Progress information

    // Debugging
    LOG_INPUT = 'I',	// Log command input
    LOG_BATCH = 'B',	// Batch input
    LOG_IO = 'O',	// Log I/O commands
    LOG_RESTORE = 'R',	// Restore operations
    LOG_TAPE = 'T',	// Tape I/O
    LOG_FULL = 'F',	// Tape full warning
    LOG_SET = 'S'	// Set constructor for restore
};

extern bool do_log_option;	// If set, log things
extern std::ofstream log_file;	// File for logging things

/********************************************************
 * log_msg -- Log a message to the file/console		*
 ********************************************************/
extern void log_msg(const char type, const std::string& msg);

/********************************************************
 * init_log -- Init general logging.			*
 ********************************************************/
extern void init_log(
    const char arg_flags[]	// The flag character from the cmd line
);

/********************************************************
 * init_console_log -- Init flags for the console 	*
 * 	logging.					*
 ********************************************************/
extern void init_console_log(
    const char arg_flags[]	// The flag character from the cmd line
);

#endif /* __LOG_H__ */
