/********************************************************
 * meta_c -- Common meta information.  (Information 	*
 * about the files in the backup.)			*
 ********************************************************/
#ifndef __META_C_H__
#define __META_C_H__

#include <set>
#include <map>

#include "types.h"
#include "io_c.h"

/********************************************************
 * Class to hold the information that describes the	*
 * back.						*
 ********************************************************/
template<typename batch_info_type, typename io_info_type>
class meta_c {
    public:
	/*
	 * Class that contains the information about a single
	 * batch.
	 */
	class gen_info {
	    public:
		// Information about the batch
		const batch_info_type* batch_info;
		// Information about the I/O
		const io_info_type* io_info;
	    public:
		gen_info(const batch_info_type* const i_batch_info,
			const io_info_type* const i_io_info):
		    batch_info(i_batch_info),
		    io_info(i_io_info) 
		{}
		gen_info(const gen_info& other):
		    batch_info(other.batch_info),
		    io_info(other.io_info) 
		{}
		//gen_info& operator = (const gen_info& other);
		// Destructor defaults
	    private:
		// No assignment operator
	};
    private:
	/*
	 * Compare the sequence number of the media/file
	 * of a batch info
	 */
	class seq_less {
	    public:
		/*
		 * Compare two info arrays
		 */
		bool operator() (
		    const gen_info& a,
		    const gen_info& b
		) {
		    if (a.io_info->media_sequence <
			b.io_info->media_sequence) {
			return (true);
		    }
		    if (a.io_info->media_sequence >
			b.io_info->media_sequence) {
			return (false);
		    }
		    return (a.io_info->file_sequence <
			    b.io_info->file_sequence);
		}
	};
    public:
	// List of batches that go into the backup
	typedef std::set<gen_info, seq_less> info_set;

	info_set info;	// The information in this backup

	// Key=file Value=File data about the file
	typedef std::map<std::string, info_set> file_data_type;

 	file_data_type file_data;	// Data translating file_name -> info

    public:
	// Constructor defaults
	~meta_c() {
	    info.erase(info.begin(), info.end());
	}
	// Destructor defaults
	void report(const std::string& file);
    protected:
	void create_file_data(void);
};
#endif /* __META_C_H__ */
