#ifndef __RAW_IO_H__
#define __RAW_IO_H__
class raw_io {
    private:
	int fd;		// FD of the file we have open
    public:
	raw_io(): fd(-1) {}
	raw_io(const char* const name,
		const int flags) {
	    assert((flags & O_CREAT) == 0);
	    if (fd >= 0)
		::close(fd);
	    fd = ::open(name, flags);
	    return (fd);
	}
	raw_io(const char* const name,
		const int flags,
		const int mode)
	{
	    assert((flags & O_CREAT) != 0);
	    if (fd >= 0)
		::close(fd);
	    fd = ::open(name, flags);
	    return (fd);
	}
	~raw_io() {
	    if (fd >= 0) {
		::close(fd);
		fd = -1;
	    }
	}
    private:
	raw_io(const& raw_io);
	raw_io& operator= (const raw_io&);
    public:
	int close(void) {
	    if (fd >= 0) {
		int result = close(fd);
		fd = -1;
		return (result);
	    }
	    return (-1);
	}
	int read(const char* const buffer, size_t size) {
	    assert(fd >= 0);
	    return (::read(fd, buffer, size));
	}
	int write(const char* const buffer, size_t size) {
	    assert(fd >= 0);
	    return (::write(fd, buffer, size));
	}
};

#endif /* __RAW_IO_H__ */
