/****************************************************************
 * tape-library 						*
 *								*
 * Library of tape i/o routines to possibly do remote access	*
 *								*
 * This library is supposed to handle file names like		*
 *		system:/dev/xxxx				*
 *	if no system: appears all calls act normally		*
 *								*
 * Routines provided						*
 *	r_open(device, mode)		open device		*
 *	r_close(fd)			close device		*
 *	r_read(fd, buffer, size)	read a buffer		*
 *	r_write(fd, buffer, size)	write a buffer		*
 *	r_ioctl(fd, func, parms)	do an ioctl		*
 ****************************************************************/

/****************************************************************
 * r_open -- open a file					*
 *								*
 * Parameters							*
 *	name -- the device name with possible system: added	*
 *	mode -- mode to use for the open			*
 *								*
 * Returns							*
 *	fd of open file						*
 *	funny fd of the open file on remote machine		*
 *	-1 for error (errno set)				*
 ****************************************************************/
extern int r_open(char *name, int mode);

/****************************************************************
 * r_close -- close the remote file				*
 *								*
 * Parameters							*
 *	fd -- the fd or phony fd to use	for the close		*
 ****************************************************************/
extern int r_close(int fd);

/****************************************************************
 * r_read -- read data from the remote fd			*
 *								*
 * Parameters							*
 *	exactly like the read system call			*
 ****************************************************************/
extern int r_read(int fd, char *buffer, int size);

/****************************************************************
 * r_write -- write to fd or remote				*
 *								*
 * Parameters							*
 *	just like system call					*
 ****************************************************************/
extern int r_write(int fd, char *buffer, int size);

/****************************************************************
 * r_ioctl -- do an ioctl on the device				*
 *								*
 * Parameters							*
 *	same as system call					*
 ****************************************************************/
extern int r_ioctl(int fd, int funct, struct mtop *mtop);

/****************************************************************
 * r_exit -- just like exit, but kill all remotes		*
 ****************************************************************/
void r_exit(int code);
