/********************************************************
 * Common data for tape I/O				*
 ********************************************************/
#ifndef __TAPE_IO_C_H__
#define __TAPE_IO_C_H__

#include <string>

#include "config.h"
#include "backup_info.h"

// Magic string for tape label
const std::string TAPE_LABEL_MAGIC("Better Backup Tape Label 1.0");

// The backup serial number
const std::string TAPE_LABEL_SERIAL("BackupSerial");

// The date of the backup
const std::string TAPE_LABEL_DATE("Date");

// The tape number
const std::string TAPE_LABEL_TAPE("Tape");

class raw_tape;
/********************************************************
 * class for labeling a tape.				*
 ********************************************************/
class tape_label {
    public:
	int label_backup_serial;	// Backup serial number
	std::string label_backup_date;	// Date of backup
	int tape_number;		// Tape number of the backup
    public:
	tape_label(void):
	    label_backup_serial(backup_serial()),
	    label_backup_date(backup_date()),
	    tape_number(-1)
	{}
	// Destructor defaults
	// Copy Constructor defaults
	// Destructor defaults
    public:
	void write(
	    raw_tape* const mt,		// Tape device to use for label
	    const std::string& device,	// Device name
	    int i_tape_number		// The tape number
	);
	void read(
	    raw_tape* const mt,		// Tape device to use for label
	    const std::string& device	// The device we are writing
	);
};
/********************************************************
 * tape_io_c -- Tape I/O common to both restore and	*
 * backup.						*
 ********************************************************/
class tape_io_c {
    protected:
	std::string device;	// Name of the device
	int block_size;		// Size of a single block
	raw_tape* mt;		// The raw I/O layer for the tape
	bool first;		// First time to write this tape?
	int file_count;		// Number of files on the current tape
	tape_label label;	// The tape label

    public:
	tape_io_c(
	    const std::string& name,	// The name of the batch
	    const config& config,	// The global configuration
	    const int mode		// Open mode
	);
	// Copy constructor defaults
	// Assignment operator
	// Destructor defaults
};

#endif /* __TAPE_IO_C_H__ */

